==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>Icono tamaño:</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--exact match--
--file: es.po--
Portable Pixel Map
X Pixel Map</translatorcomment>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--exact match--
--file: es.po--
Espacio mínimo en la cuadrícula (pxl):
Espacio mínimo en la cuadrícula (pxl)
Fuji PXG</translatorcomment>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translation>Columnas:</translation>
    </message>
    <message>
        <location filename="../CadToolBar.js" line="+49"/>
        <source>Widgets</source>
        <translatorcomment>--google--
Seleccionador de varios métodos de entrada que usa el menú contextual de los elementos de texto</translatorcomment>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>Barra de herramientas CAD</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Toggle Title Bar</source>
        <translation>Mostrar barra de título</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Barra de herramientas CAD</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+76"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/CadToolBar/ts/CadToolBar_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>CadToolBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>Icono tamaño:</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>Pixel</source>
        <translatorcomment>--exact match--
--file: es.po--
Portable Pixel Map
X Pixel Map</translatorcomment>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translatorcomment>--exact match--
--file: es.po--
Espacio mínimo en la cuadrícula (pxl):
Espacio mínimo en la cuadrícula (pxl)
Fuji PXG</translatorcomment>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Columns:</source>
        <translation>Columnas:</translation>
    </message>
    <message>
        <location filename="../CadToolBar.js" line="+51"/>
        <source>Widgets</source>
        <translatorcomment>--google--
Seleccionador de varios métodos de entrada que usa el menú contextual de los elementos de texto</translatorcomment>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>CAD Toolbar</source>
        <translation>Barra de herramientas CAD</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertical / Horizontal</translation>
    </message>
    <message>
        <source>Toggle Title Bar</source>
        <translation type="vanished">Mostrar barra de título</translation>
    </message>
    <message>
        <source>CAD Tool Bar</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Barra de herramientas CAD</translation>
    </message>
</context>
<context>
    <name>CadToolBarPanel</name>
    <message>
        <location filename="../CadToolBarPanel.js" line="+107"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
</context>
</TS>
